@@ -1341,7 +1341,7 @@ where
                     if usage.ref_count != 1 {
                         return Ok(false);
                     }
-                    if usage.reassigned || !usage.is_fn_local {
+                    if usage.reassigned() || !usage.is_fn_local {
                         return Ok(false);
                     }
                     if usage.inline_prevented {
